@@ -23,30 +23,22 @@ def get_template_path(template_name):
     return os.path.join(cookiecutters_path, template_name)
     
 
-def install_requirements():
-    """
-    Creates a virtual environment and installs the requirements
-    """
+def activate_venv():
 
     parent = os.getcwd()
-    # full_path = os.path.join(parent, name)
-    # os.chdir(full_path)
     os.system("python -m venv env")
 
-    env_sub_dir = ""
-    source = ""
+    env_activate_script = ""
     if OS == "Windows":
-        env_sub_dir = "Scripts"
-    else:
-        env_sub_dir = "bin"
-        source = ". "
+        env_activate_script = "Scripts"
 
-    activate_file = os.path.join(parent, "env", env_sub_dir, "activate")
-    os.system(f"{source}{activate_file} && pip install -r requirements.txt")
+
+    activate_file = os.path.join(parent, "env", env_activate_script, "activate")
+    os.system(f"{activate_file} && pip install -r requirements.txt")
 
 @app.command()
 def main(template_name):
     cookiecutter("https://github.com/MohammedBajuaifer/drf-starter-templates.git")
 
-    install_requirements()
+    activate_venv()
 
